package cz.zcu.mjaneck.bak_prace.app;

import java.io.IOException;
import java.io.InputStream;
import java.text.SimpleDateFormat;
import java.util.Properties;

/**
 * Třída obsahující pomocné metody
 */
public class Utility {

    /** Soubor se zdrojema řetězců */
    private static final String PROPERTIES_FILE = "string_resources.properties";
    /** Konstanta velikosti int v bajtech */
    private static final int INTEGER_BYTES = 4;
    /** Formát zobrazovaného času */
    private static final String TIME_FORMAT_PATTERN = "HH:mm";
    /** Offset času */
    private static final int TIME_OFFSET = 3600000;

    /**
     * Zvětší pole velikosti dva na pole velikosti čtyři
     * @param arrayIn - Vstupní pole o veliksoti 2
     * @return - Pole o velikosti 4
     */
    public static byte[] expandArray(byte[] arrayIn) {

        if (arrayIn.length >= 4 || arrayIn.length < 1)
            return arrayIn;

        int emptyArrayLen = INTEGER_BYTES - arrayIn.length;
        byte[] expandedArray = new byte[INTEGER_BYTES];

        System.arraycopy(new byte[emptyArrayLen], 0, expandedArray, 0, emptyArrayLen);
        System.arraycopy(arrayIn, 0, expandedArray, emptyArrayLen, arrayIn.length);

        return expandedArray;
    }

    /**
     * Vrací sformátovaný čas
     * @param time - Hodnota času
     * @return - Řetězec s formátovaným časem
     */
    public static String getFormattedTime(long time) {
        return new SimpleDateFormat(TIME_FORMAT_PATTERN).format(time);
    }

    /**
     * Vrací uplnynulý čas
     * @param startTime - Čas začátku
     * @return - Uplynulý čas
     */
    public static long getElapsedTime(long startTime) {
        return System.currentTimeMillis() - startTime - TIME_OFFSET;
    }

    /**
     * Načítá řetězcové zdroje
     * @return - Proměnná s řetězci
     */
    public static Properties loadPropertiesFile() {
        Properties properties = new Properties();

        try {
            InputStream inStream = Utility.class.getClassLoader().getResourceAsStream(PROPERTIES_FILE);

            if (inStream != null)
                properties.load(inStream);

        } catch (IOException e) {
            e.printStackTrace();
            return null;
        }

        return properties;
    }

}
